# 支付宝间连证书上传
add_cert_url = "/v2/pcredit/certificate/config"
# 创建花呗分期商家贴息方案
create_solution = "/v2/pcredit/solution/create"
# 上架/下架花呗分期贴息
modify_solution_status = "/v2/pcredit/statue/modify"
# 更新花呗分期商家贴息方案
modify_solution = "/v2/pcredit/solution/modify"
# 查询花呗分期贴息
query_solution = "/v2/pcredit/order/query"
# 花呗活动详情查询
query_act_detail = "/v2/pcredit/solution/query"
