# 签约版-换取应用授权令牌
exchange_app_auth_token = "/ssproxy/direct/exchangeAppAuthToken"
# 签约版-申请当面付代签约
apply_face_to_face_sign = "/ssproxy/direct/applyFaceToFaceSign"
# 签约版-查询申请状态
query_apply_order_status = "/ssproxy/direct/queryApplyOrderStatus"
# 直付通-商户进件申请
reg_zft_mer_info = "/ssproxy/direct/regZftMerInfo"
# 直付通-分账关系绑定&解绑
config_zft_split_receiver = "/ssproxy/direct/configZftSplitReceiver"
# 直付通-分账关系查询
query_zft_split_receiver = "/ssproxy/direct/queryZftSplitReceiver"
