# 企业类型商户进件
ent_mer_reg = "/v2/merchant/basicdata/ent"
# 个体户类型商户进件
indv_mer_reg = "/v2/merchant/basicdata/indv"
# 基本信息修改
mer_modify = "/v2/merchant/basicdata/modify"
# 详细信息查询
query_merch_info = "/v2/merchant/basicdata/query"
# 新增总部
add_chains_corp_info = "/v2/merchant/chains/corpinfo"
# 修改总部
modify_chains_corp_info = "/v2/merchant/chains/modify"
# 总部商户绑定&解除
bind_chains_mer = "/v2/merchant/chains/bind"
# 商户业务开通
reg_mer_busi_info = "/v2/merchant/busi/open"
# 商户业务开通修改
modify_mer_busi_info = "/v2/merchant/busi/modify"
# 申请单状态查询
query_apply_status = "/v2/merchant/basicdata/status/query"

# 对账单下载
mer_file_download = "/v2/trade/check/filequery"
# 商户分期配置
config_fq_mer_free = "/v2/pcredit/fee/config"
# 商户分期配置详情查询
query_fq_mer_free_detail = "/v2/pcredit/fee/detail"
# 活动报名，支持微信
reg_activities = "/v2/merchant/activity/add"
# 活动报名查询
query_act_url = "/v2/merchant/activity/query"
# 结算记录查询
settlement_query = '/v2/merchant/basicdata/settlement/query'

# 商户图片资料上传
mer_file_upload = "/ssproxy/file/upload"
# mer_file_upload = "/v2/supplementary/picture"

# 查询账户信息
query_acct_info_list = "/ssproxy/queryAcctInfoList"
# 商户分账配置
add_mer_split_config = "/ssproxy/addMerSplitConfig"
# 商户分账配置查询
query_mer_split_config = "/ssproxy/queryMerSplitConfig"


add_cert_info = "/ssproxy/direct/addCertInfo"
