# 企业用户基本信息注册
reg_usr_ent_base_info = "/v2/user/basicdata/ent"
# 个人用户基本信息注册
reg_usr_indv_base_info = "/v2/user/basicdata/indv"
# 企业用户基本信息修改
modify_usr_ent_base_info = "/v2/user/basicdata/ent/modify"
# 个人用户基本信息修改
modify_use_indv_base_info = "/v2/user/basicdata/indv/modify"
# 用户业务入驻
reg_usr_busi_info = "/v2/user/busi/open"
# 用户业务查询
query_user_detail = "/v2/user/basicdata/query"
