# 云闪付活动商户入驻
reg_mer_base_info = "/ssproxy/registeMerBaseInfo"
# 云闪付活动商户入驻状态查询
query_mer_reg_stat = "/ssproxy/queryMerRegisteStatus"
# 云闪付活动商户详细信息查询
query_mer_base = "/ssproxy/queryMerBaseInfo"
# 云闪付活动列表查询
query_act_list = "/ssproxy/queryActivityList"
# 云闪付活动报名
enlist_act = "/ssproxy/enlistActivity"
# 云闪付活动报名进度查询
query_en_list_act_stat = "/ssproxy/queryEnlistActivityStatus"
