# 微信商户配置
config = "/v2/merchant/busi/config"
# 微信商户配置查询
query_config = "/v2/merchant/busi/config/query"
# 微信实名认证
apply_wx_real_name = "/v2/merchant/busi/realname"
# 微信实名认证状态查询
query_apply_wx_real_name = "/v2/merchant/busi/realname/query"
# 微信特约商户进件申请
apply_wx_special_mer_sign = "/ssproxy/direct/applyWxSpecialMerSign"
# 查询微信申请状态
query_wx_special_mer_sign = "/ssproxy/direct/queryWxSpecialMerSign"
# 修改微信结算帐号
modify_wx_settle_info = "/ssproxy/direct/modifyWxSettlementInfo"
# 查询微信结算账户
query_wx_settle_info = "/ssproxy/direct/queryWxSettlementInfo"
# 微信关注配置
wx_subscribe_config = "/ssproxy/direct/wxSubscribeConfig"
# 微信关注配置查询
query_wx_subscribe_config = "/ssproxy/direct/queryWxSubscribeConfig"
